Lars Kneschke wrote:
> Making a connection to the DBMail IMAP server and login in: 0.2 seconds
> 
> Sorting a folder with more than 1000 messages by subject: 0.09 seconds
> 
> Fetching the headers of 10 messages from the result: 1 second
> 
> Overall time spend in the php script: 1.3 seconds.
> 
> Puh, that  times slower. :-(
> 
> I started using iampproxy to speed up the login process. But that
> changed nothing. I don't know why. But the login process still took the
> same time. Imapproxy stated that it was reusing a session.
> 
> DBmail spends most time fetching the headers from the database. 

This has now been fixed!

> 
> Then i took the sql queries generated by dbmail from the log file. Only
> executing the sql queries against the database over the network from the
> IMAP server and forwarding the results to /dev/null took 0.5 seconds.
> Doing the same queries on the database itself only took 0.05 seconds.
> 
> As dbmail is doing very much single sql queries it should benefit much
> from doing more things in a single sql query, as every query adds
> another delay because of the round trip time from the imap server to the
> sql server.


Now how about running your test with the latest svn codebase?

It does require an additional table (dbmail_envelopes) and a dbmail-util
-by run, but after that I would expect very significant improvement in
throughput indeed.


-- 
  ________________________________________________________________
  Paul Stevens                                      paul at nfg.nl
  NET FACILITIES GROUP                     GPG/PGP: 1024D/11F8CD31
  The Netherlands________________________________http://www.nfg.nl

Reply via email to